import { CustomEventTarget } from '../lib/CustomEventTarget';
import { Config, ListenerCallback } from '../types/shared';
declare type requiredConfigs = Pick<Config, "region" | "IdentityPoolId">;
declare type optionalConfigs = Omit<Config, "region" | "IdentityPoolId">;
declare type configArgs = requiredConfigs & Partial<optionalConfigs>;
declare class AWSRecognizer extends CustomEventTarget implements SpeechRecognition {
    /** in case future recognizers are built in the future (e.g. Azure) */
    static type: string;
    /** true if the library is supported by the currenly browser */
    static isSupported: boolean;
    /** polyfill-specific config */
    config: Config;
    /** if the library is currently capturing/transcribing audio */
    listening: boolean;
    /** the langage (default en-US) */
    lang: Config['lang'];
    /** whether to continously transribe audio until .stop() is called */
    continuous: boolean;
    /** a proxy for new AWSRecognizer(config) */
    static create(config: Config): void;
    constructor(config: configArgs);
    /** start capturing/transcribing audio */
    start(): void;
    /** stop capturing and return any final transcriptions */
    stop(): void;
    /** stop capturing and don't emit any transcibed audio */
    abort(): void;
    /** dispatch transcription result */
    private emitResult;
    /** dispatch error event */
    private emitError;
    /** dispatch events related to sound start */
    private emitSoundStart;
    /** dispatch events realated to sound end */
    private emitSoundEnd;
    /** authenticate and connect to AWS Transcribe */
    private establishConnection;
    /** get a signed url using specified credentials */
    private getSignedURL;
    /** handle streaming received audio buffer to AWS transcribe */
    private streamAudioToWebSocket;
    /** handle websocket responses */
    private handleSocketMessages;
    set interimResults(_: boolean);
    get interimResults(): boolean;
    set maxAlternatives(_: number);
    get maxAlternatives(): number;
    set grammars(_: SpeechGrammarList);
    get grammars(): SpeechGrammarList;
    set onaudiostart(fn: ListenerCallback);
    set onaudioend(fn: ListenerCallback);
    set onend(fn: ListenerCallback);
    set onerror(fn: ListenerCallback);
    set onnomatch(fn: ListenerCallback);
    set onresult(fn: ListenerCallback);
    set onsoundstart(fn: ListenerCallback);
    set onsoundend(fn: ListenerCallback);
    set onspeechstart(fn: ListenerCallback);
    set onspeechend(fn: ListenerCallback);
    set onstart(fn: ListenerCallback);
}
export default AWSRecognizer;
